@@ -28,7 +28,7 @@ Usage::
 """
 from datetime import datetime
 from decimal import Decimal
-from typing import Any, Dict, Generic, Iterator, List, Set, TypeVar, Union
+from typing import Any, Generic, Iterator, Mapping, Sequence, Set, TypeVar, Union
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -70,7 +70,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListBackupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listbackupspaginator)
     """
 
@@ -84,14 +84,14 @@ class ListBackupsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListBackupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.ListBackups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listbackupspaginator)
         """
 
 
 class ListTablesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtablespaginator)
     """
 
@@ -99,14 +99,14 @@ class ListTablesPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListTablesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.ListTables.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtablespaginator)
         """
 
 
 class ListTagsOfResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtagsofresourcepaginator)
     """
 
@@ -114,14 +114,14 @@ class ListTagsOfResourcePaginator(Boto3Paginator):
         self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListTagsOfResourceOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.ListTagsOfResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#listtagsofresourcepaginator)
         """
 
 
 class QueryPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.Query)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#querypaginator)
     """
 
@@ -131,18 +131,18 @@ class QueryPaginator(Boto3Paginator):
         TableName: str,
         IndexName: str = None,
         Select: SelectType = None,
-        AttributesToGet: List[str] = None,
+        AttributesToGet: Sequence[str] = None,
         ConsistentRead: bool = None,
-        KeyConditions: Dict[str, "ConditionTypeDef"] = None,
-        QueryFilter: Dict[str, "ConditionTypeDef"] = None,
+        KeyConditions: Mapping[str, "ConditionTypeDef"] = None,
+        QueryFilter: Mapping[str, "ConditionTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ScanIndexForward: bool = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ProjectionExpression: str = None,
         FilterExpression: str = None,
         KeyConditionExpression: str = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[
+        ExpressionAttributeNames: Mapping[str, str] = None,
+        ExpressionAttributeValues: Mapping[
             str,
             Union[
                 bytes,
@@ -156,22 +156,22 @@ class QueryPaginator(Boto3Paginator):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[QueryOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.Query.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#querypaginator)
         """
 
 
 class ScanPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.Scan)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#scanpaginator)
     """
 
@@ -180,17 +180,17 @@ class ScanPaginator(Boto3Paginator):
         *,
         TableName: str,
         IndexName: str = None,
-        AttributesToGet: List[str] = None,
+        AttributesToGet: Sequence[str] = None,
         Select: SelectType = None,
-        ScanFilter: Dict[str, "ConditionTypeDef"] = None,
+        ScanFilter: Mapping[str, "ConditionTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         TotalSegments: int = None,
         Segment: int = None,
         ProjectionExpression: str = None,
         FilterExpression: str = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[
+        ExpressionAttributeNames: Mapping[str, str] = None,
+        ExpressionAttributeValues: Mapping[
             str,
             Union[
                 bytes,
@@ -204,8 +204,8 @@ class ScanPaginator(Boto3Paginator):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None,
@@ -213,6 +213,6 @@ class ScanPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ScanOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Paginator.Scan.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/paginators.html#scanpaginator)
         """
