@@ -18,7 +18,7 @@ Usage::
 """
 from datetime import datetime
 from decimal import Decimal
-from typing import Any, Dict, Iterator, List, Set, Union
+from typing import Any, Dict, Iterator, List, Mapping, Sequence, Set, Union
 
 from boto3.dynamodb.conditions import ConditionBase
 from boto3.dynamodb.table import BatchWriter
@@ -67,7 +67,7 @@ __all__ = ("DynamoDBServiceResource", "Table", "ServiceResourceTablesCollection"
 
 class ServiceResourceTablesCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource.tables)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#serviceresourcetablescollection)
     """
 
@@ -106,7 +106,7 @@ class ServiceResourceTablesCollection(ResourceCollection):
 
 class Table(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#table)
     """
 
@@ -137,7 +137,7 @@ class Table(Boto3ServiceResource):
         """
         Create a batch writer object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.batch_writer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablebatch_writer-method)
         """
 
@@ -145,14 +145,14 @@ class Table(Boto3ServiceResource):
         """
         The `DeleteTable` operation deletes a table and all of its items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete-method)
         """
 
     def delete_item(
         self,
         *,
-        Key: Dict[
+        Key: Mapping[
             str,
             Union[
                 bytes,
@@ -166,19 +166,19 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ],
-        Expected: Dict[str, "ExpectedAttributeValueTypeDef"] = None,
+        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ReturnValues: ReturnValueType = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
         ConditionExpression: str = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[
+        ExpressionAttributeNames: Mapping[str, str] = None,
+        ExpressionAttributeValues: Mapping[
             str,
             Union[
                 bytes,
@@ -192,8 +192,8 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None
@@ -201,22 +201,22 @@ class Table(Boto3ServiceResource):
         """
         Deletes a single item in a table by primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.delete_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tabledelete_item-method)
         """
 
-    def get_available_subresources(self) -> List[str]:
+    def get_available_subresources(self) -> Sequence[str]:
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_available_subresources-method)
         """
 
     def get_item(
         self,
         *,
-        Key: Dict[
+        Key: Mapping[
             str,
             Union[
                 bytes,
@@ -230,22 +230,22 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ],
-        AttributesToGet: List[str] = None,
+        AttributesToGet: Sequence[str] = None,
         ConsistentRead: bool = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ProjectionExpression: str = None,
-        ExpressionAttributeNames: Dict[str, str] = None
+        ExpressionAttributeNames: Mapping[str, str] = None
     ) -> GetItemOutputTypeDef:
         """
         The `GetItem` operation returns a set of attributes for the item with the given
         primary key.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableget_item-method)
         """
 
@@ -254,14 +254,14 @@ class Table(Boto3ServiceResource):
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
         Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableload-method)
         """
 
     def put_item(
         self,
         *,
-        Item: Dict[
+        Item: Mapping[
             str,
             Union[
                 bytes,
@@ -275,19 +275,19 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ],
-        Expected: Dict[str, "ExpectedAttributeValueTypeDef"] = None,
+        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = None,
         ReturnValues: ReturnValueType = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ConditionExpression: str = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[
+        ExpressionAttributeNames: Mapping[str, str] = None,
+        ExpressionAttributeValues: Mapping[
             str,
             Union[
                 bytes,
@@ -301,8 +301,8 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None
@@ -310,7 +310,7 @@ class Table(Boto3ServiceResource):
         """
         Creates a new item, or replaces an old item with a new item.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.put_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.put_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableput_item-method)
         """
 
@@ -319,14 +319,14 @@ class Table(Boto3ServiceResource):
         *,
         IndexName: str = None,
         Select: SelectType = None,
-        AttributesToGet: List[str] = None,
+        AttributesToGet: Sequence[str] = None,
         Limit: int = None,
         ConsistentRead: bool = None,
-        KeyConditions: Dict[str, "ConditionTypeDef"] = None,
-        QueryFilter: Dict[str, "ConditionTypeDef"] = None,
+        KeyConditions: Mapping[str, "ConditionTypeDef"] = None,
+        QueryFilter: Mapping[str, "ConditionTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ScanIndexForward: bool = None,
-        ExclusiveStartKey: Dict[
+        ExclusiveStartKey: Mapping[
             str,
             Union[
                 bytes,
@@ -340,8 +340,8 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None,
@@ -349,8 +349,8 @@ class Table(Boto3ServiceResource):
         ProjectionExpression: str = None,
         FilterExpression: Union[str, ConditionBase] = None,
         KeyConditionExpression: Union[str, ConditionBase] = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[
+        ExpressionAttributeNames: Mapping[str, str] = None,
+        ExpressionAttributeValues: Mapping[
             str,
             Union[
                 bytes,
@@ -364,8 +364,8 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None
@@ -373,7 +373,7 @@ class Table(Boto3ServiceResource):
         """
         The `Query` operation finds items based on primary key values.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.query)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.query)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablequery-method)
         """
 
@@ -382,7 +382,7 @@ class Table(Boto3ServiceResource):
         Calls :py:meth:`DynamoDB.Client.describe_table` to update the attributes of the
         Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablereload-method)
         """
 
@@ -390,12 +390,12 @@ class Table(Boto3ServiceResource):
         self,
         *,
         IndexName: str = None,
-        AttributesToGet: List[str] = None,
+        AttributesToGet: Sequence[str] = None,
         Limit: int = None,
         Select: SelectType = None,
-        ScanFilter: Dict[str, "ConditionTypeDef"] = None,
+        ScanFilter: Mapping[str, "ConditionTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
-        ExclusiveStartKey: Dict[
+        ExclusiveStartKey: Mapping[
             str,
             Union[
                 bytes,
@@ -409,8 +409,8 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None,
@@ -419,8 +419,8 @@ class Table(Boto3ServiceResource):
         Segment: int = None,
         ProjectionExpression: str = None,
         FilterExpression: Union[str, ConditionBase] = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[
+        ExpressionAttributeNames: Mapping[str, str] = None,
+        ExpressionAttributeValues: Mapping[
             str,
             Union[
                 bytes,
@@ -434,8 +434,8 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None,
@@ -445,33 +445,33 @@ class Table(Boto3ServiceResource):
         The `Scan` operation returns one or more items and item attributes by accessing
         every item in a table or a secondary index.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.scan)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.scan)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablescan-method)
         """
 
     def update(
         self,
         *,
-        AttributeDefinitions: List["AttributeDefinitionTypeDef"] = None,
+        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"] = None,
         BillingMode: BillingModeType = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
-        GlobalSecondaryIndexUpdates: List["GlobalSecondaryIndexUpdateTypeDef"] = None,
+        GlobalSecondaryIndexUpdates: Sequence["GlobalSecondaryIndexUpdateTypeDef"] = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: "SSESpecificationTypeDef" = None,
-        ReplicaUpdates: List["ReplicationGroupUpdateTypeDef"] = None
+        ReplicaUpdates: Sequence["ReplicationGroupUpdateTypeDef"] = None
     ) -> "_Table":
         """
         Modifies the provisioned throughput settings, global secondary indexes, or
         DynamoDB Streams settings for a given table.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate-method)
         """
 
     def update_item(
         self,
         *,
-        Key: Dict[
+        Key: Mapping[
             str,
             Union[
                 bytes,
@@ -485,21 +485,21 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ],
-        AttributeUpdates: Dict[str, "AttributeValueUpdateTypeDef"] = None,
-        Expected: Dict[str, "ExpectedAttributeValueTypeDef"] = None,
+        AttributeUpdates: Mapping[str, "AttributeValueUpdateTypeDef"] = None,
+        Expected: Mapping[str, "ExpectedAttributeValueTypeDef"] = None,
         ConditionalOperator: ConditionalOperatorType = None,
         ReturnValues: ReturnValueType = None,
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None,
         UpdateExpression: str = None,
         ConditionExpression: str = None,
-        ExpressionAttributeNames: Dict[str, str] = None,
-        ExpressionAttributeValues: Dict[
+        ExpressionAttributeNames: Mapping[str, str] = None,
+        ExpressionAttributeValues: Mapping[
             str,
             Union[
                 bytes,
@@ -513,8 +513,8 @@ class Table(Boto3ServiceResource):
                 Set[str],
                 Set[bytes],
                 Set[bytearray],
-                List[Any],
-                Dict[str, Any],
+                Sequence[Any],
+                Mapping[str, Any],
                 None,
             ],
         ] = None
@@ -523,7 +523,7 @@ class Table(Boto3ServiceResource):
         Edits an existing item's attributes, or adds a new item to the table if it does
         not already exist.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.update_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.update_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tableupdate_item-method)
         """
 
@@ -531,7 +531,7 @@ class Table(Boto3ServiceResource):
         """
         Waits until this Table is exists.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.wait_until_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_exists-method)
         """
 
@@ -539,7 +539,7 @@ class Table(Boto3ServiceResource):
         """
         Waits until this Table is not exists.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.Table.wait_until_not_exists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#tablewait_until_not_exists-method)
         """
 
@@ -553,7 +553,7 @@ class DynamoDBResourceMeta(ResourceMeta):
 
 class DynamoDBServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html)
     """
 
@@ -564,28 +564,28 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         """
         Creates a Table resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource.Table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcetable-method)
         """
 
     def batch_get_item(
         self,
         *,
-        RequestItems: Dict[str, "KeysAndAttributesTypeDef"],
+        RequestItems: Mapping[str, "KeysAndAttributesTypeDef"],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None
     ) -> BatchGetItemOutputTypeDef:
         """
         The `BatchGetItem` operation returns the attributes of one or more items from
         one or more tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_get_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_get_item-method)
         """
 
     def batch_write_item(
         self,
         *,
-        RequestItems: Dict[str, List["WriteRequestTypeDef"]],
+        RequestItems: Mapping[str, Sequence["WriteRequestTypeDef"]],
         ReturnConsumedCapacity: ReturnConsumedCapacityType = None,
         ReturnItemCollectionMetrics: ReturnItemCollectionMetricsType = None
     ) -> BatchWriteItemOutputTypeDef:
@@ -593,35 +593,35 @@ class DynamoDBServiceResource(Boto3ServiceResource):
         The `BatchWriteItem` operation puts or deletes multiple items in one or more
         tables.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource.batch_write_item)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcebatch_write_item-method)
         """
 
     def create_table(
         self,
         *,
-        AttributeDefinitions: List["AttributeDefinitionTypeDef"],
+        AttributeDefinitions: Sequence["AttributeDefinitionTypeDef"],
         TableName: str,
-        KeySchema: List["KeySchemaElementTypeDef"],
-        LocalSecondaryIndexes: List["LocalSecondaryIndexTypeDef"] = None,
-        GlobalSecondaryIndexes: List["GlobalSecondaryIndexTypeDef"] = None,
+        KeySchema: Sequence["KeySchemaElementTypeDef"],
+        LocalSecondaryIndexes: Sequence["LocalSecondaryIndexTypeDef"] = None,
+        GlobalSecondaryIndexes: Sequence["GlobalSecondaryIndexTypeDef"] = None,
         BillingMode: BillingModeType = None,
         ProvisionedThroughput: "ProvisionedThroughputTypeDef" = None,
         StreamSpecification: "StreamSpecificationTypeDef" = None,
         SSESpecification: "SSESpecificationTypeDef" = None,
-        Tags: List["TagTypeDef"] = None
+        Tags: Sequence["TagTypeDef"] = None
     ) -> _Table:
         """
         The `CreateTable` operation adds a new table to your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource.create_table)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourcecreate_table-method)
         """
 
-    def get_available_subresources(self) -> List[str]:
+    def get_available_subresources(self) -> Sequence[str]:
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/dynamodb.html#DynamoDB.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dynamodb/service_resource.html#dynamodbserviceresourceget_available_subresources-method)
         """
